# AWS data

## Sources

- AWS JS SDK v2 (JSON schema), used by `aws2openapi` to generate the `openapi-directory` repo
  OpenAPI schemas for AWS APIs
- AWS JS SDK v3 (Amazon Smithy schema)

Retrieved on 9th June 2023

via ...
